@@ -144,14 +144,12 @@ GstRenderer.prototype = {
     createToolbar : function () {
         this._mainToolbar = new Gtk.Toolbar({ icon_size: Gtk.IconSize.MENU });
         this._mainToolbar.get_style_context().add_class('osd');
+        this._mainToolbar.set_show_arrow(false);
         this._mainToolbar.show();
 
         this._toolbarActor = new GtkClutter.Actor({ contents: this._mainToolbar,
-                                                    opacity: 0 });
-        this._toolbarActor.add_constraint(
-            new Clutter.BindConstraint({ source: this._video,
-                                         coordinate: Clutter.BindCoordinate.WIDTH,
-                                         offset: -50 }));
+                                                    opacity: 0,
+                                                    x_expand: true });
 
         this._toolbarPlay = new Gtk.ToolButton({ icon_name: 'media-playback-pause-symbolic' });
         this._toolbarPlay.show();
