@@ -57,8 +57,12 @@ enum {
   PROP_TIME,
   PROP_FILE,
   PROP_CONTENT_TYPE,
+  PROP_FILE_TYPE,
+  NUM_PROPERTIES
 };
 
+static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
+
 typedef struct {
   SushiFileLoader *self;
 
@@ -358,6 +362,7 @@ query_info_async_ready_cb (GObject *source,
   g_object_notify (G_OBJECT (self), "name");
   g_object_notify (G_OBJECT (self), "time");
   g_object_notify (G_OBJECT (self), "content-type");
+  g_object_notify (G_OBJECT (self), "file-type");
 
   if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY) {
     self->priv->loading = FALSE;
@@ -440,6 +445,9 @@ sushi_file_loader_get_property (GObject *object,
   case PROP_CONTENT_TYPE:
     g_value_take_string (value, sushi_file_loader_get_content_type_string (self));
     break;
+  case PROP_FILE_TYPE:
+    g_value_set_enum (value, sushi_file_loader_get_file_type (self));
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -474,61 +482,52 @@ sushi_file_loader_class_init (SushiFileLoaderClass *klass)
   oclass->get_property = sushi_file_loader_get_property;
   oclass->set_property = sushi_file_loader_set_property;
 
-  g_object_class_install_property
-    (oclass,
-     PROP_FILE,
-     g_param_spec_object ("file",
-                          "File",
-                          "The loaded file",
-                          G_TYPE_FILE,
-                          G_PARAM_READWRITE));
-
-  g_object_class_install_property
-    (oclass,
-     PROP_NAME,
-     g_param_spec_string ("name",
-                          "Name",
-                          "The display name",
-                          NULL,
-                          G_PARAM_READABLE));
-
-  g_object_class_install_property
-    (oclass,
-     PROP_SIZE,
-     g_param_spec_string ("size",
-                          "Size",
-                          "The size string",
-                          NULL,
-                          G_PARAM_READABLE));
-
-  g_object_class_install_property
-    (oclass,
-     PROP_TIME,
-     g_param_spec_string ("time",
-                          "Time",
-                          "The time string",
-                          NULL,
-                          G_PARAM_READABLE));
-
-  g_object_class_install_property
-    (oclass,
-     PROP_CONTENT_TYPE,
-     g_param_spec_string ("content-type",
-                          "Content Type",
-                          "The content type",
-                          NULL,
-                          G_PARAM_READABLE));
-  
-  g_object_class_install_property
-    (oclass,
-     PROP_ICON,
-     g_param_spec_object ("icon",
-                          "Icon",
-                          "The icon of the file",
-                          GDK_TYPE_PIXBUF,
-                          G_PARAM_READABLE));
+  properties[PROP_FILE] =
+    g_param_spec_object ("file",
+                         "File",
+                         "The loaded file",
+                         G_TYPE_FILE,
+                         G_PARAM_READWRITE);
+  properties[PROP_NAME] =
+    g_param_spec_string ("name",
+                         "Name",
+                         "The display name",
+                         NULL,
+                         G_PARAM_READABLE);
+  properties[PROP_SIZE] =
+    g_param_spec_string ("size",
+                         "Size",
+                         "The size string",
+                         NULL,
+                         G_PARAM_READABLE);
+  properties[PROP_TIME] =
+    g_param_spec_string ("time",
+                         "Time",
+                         "The time string",
+                         NULL,
+                         G_PARAM_READABLE);
+  properties[PROP_CONTENT_TYPE] =
+    g_param_spec_string ("content-type",
+                         "Content Type",
+                         "The content type",
+                         NULL,
+                         G_PARAM_READABLE);
+  properties[PROP_FILE_TYPE] =
+    g_param_spec_enum ("file-type",
+                       "File Type",
+                       "The file type",
+                       G_TYPE_FILE_TYPE,
+                       G_FILE_TYPE_UNKNOWN,
+                       G_PARAM_READABLE);
+  properties[PROP_ICON] =
+    g_param_spec_object ("icon",
+                         "Icon",
+                         "The icon of the file",
+                         GDK_TYPE_PIXBUF,
+                         G_PARAM_READABLE);
 
   g_type_class_add_private (klass, sizeof (SushiFileLoaderPrivate));
+  g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 }
 
 static void
@@ -689,7 +688,7 @@ sushi_file_loader_get_date_string (SushiFileLoader *self)
 }
 
 /**
- * sushi_file_loader_get_date_string:
+ * sushi_file_loader_get_content_type_string:
  * @self:
  *
  * Returns: (transfer full):
@@ -703,6 +702,21 @@ sushi_file_loader_get_content_type_string (SushiFileLoader *self)
   return g_content_type_get_description (g_file_info_get_content_type (self->priv->info));
 }
 
+/**
+ * sushi_file_loader_get_file_type:
+ * @self:
+ *
+ * Returns:
+ */
+GFileType
+sushi_file_loader_get_file_type (SushiFileLoader *self)
+{
+  if (self->priv->info == NULL)
+    return G_FILE_TYPE_UNKNOWN;
+
+  return g_file_info_get_file_type (self->priv->info);
+}
+
 void
 sushi_file_loader_stop (SushiFileLoader *self)
 {
